[mapserver-commits] r10291 - trunk/mapserver

svn at osgeo.org svn at osgeo.org
Tue Jul 6 11:25:00 EDT 2010


Author: aboudreault
Date: 2010-07-06 15:25:00 +0000 (Tue, 06 Jul 2010)
New Revision: 10291

Modified:
   trunk/mapserver/mapogr.cpp
Log:
Replaced isalpha by isnum for #3481

Modified: trunk/mapserver/mapogr.cpp
===================================================================
--- trunk/mapserver/mapogr.cpp	2010-07-06 15:08:44 UTC (rev 10290)
+++ trunk/mapserver/mapogr.cpp	2010-07-06 15:25:00 UTC (rev 10291)
@@ -2853,11 +2853,11 @@
 
               // Enclose the text string inside quotes to make sure it is seen
               // as a string by the parser inside loadExpression(). (bug185)
               /* See bug 3481 about the isalpha hack */
               const char *labelTextString = OGR_ST_GetParamStr(hLabelStyle, 
                                                                OGRSTLabelTextString, 
                                                                &bIsNull);
-              if (labelTextString && isalpha(labelTextString[0]))
+              if (labelTextString && isalnum(labelTextString[0]))
                   msLoadExpressionString(&(c->text), (char*)labelTextString);
               else
                   msLoadExpressionString(&(c->text), 
@@ -2992,10 +2992,10 @@
 
               // Enclose the text string inside quotes to make sure it is seen
               // as a string by the parser inside loadExpression(). (bug185)
               /* See bug 3481 about the isalpha hack */
               const char *labelTextString = poLabelStyle->TextString(bIsNull);
 
-              if (labelTextString && isalpha(labelTextString[0]))
+              if (labelTextString && isalnum(labelTextString[0]))
                   msLoadExpressionString(&(c->text), (char*)labelTextString);
               else
                   msLoadExpressionString(&(c->text), 
@@ -2853,11 +2853,11 @@
               // Enclose the text string inside quotes to make sure it is seen
               // as a string by the parser inside loadExpression(). (bug185)
-              /* See bug 3481 about the isalpha hack */
+              /* See bug 3481 about the isalnum hack */
               const char *labelTextString = OGR_ST_GetParamStr(hLabelStyle, 
                                                                OGRSTLabelTextString, 
@@ -2992,10 +2992,10 @@
               // Enclose the text string inside quotes to make sure it is seen
               // as a string by the parser inside loadExpression(). (bug185)
-              /* See bug 3481 about the isalpha hack */
+              /* See bug 3481 about the isalnum hack */
               const char *labelTextString = poLabelStyle->TextString(bIsNull);
 



More information about the mapserver-commits mailing list